@@ -1,6 +1,6 @@
 import requests
 
-from build.lib.bf_engine.logger import log
+from ..logger import log
 from .base import CallerBase
 from ..config import Config
 from ..entity.enums import QuestionType, QuestionMode, QuestionField
@@ -517,13 +517,15 @@ class QACaller(CallerBase):
         if("answers" in data.keys()):
              answer_request_list = data.get("answers")
              if(len(answer_request_list) > 0):
-               ans_resp = requests.get(self.upload_faq_json_sq_url + "/" + str(question_id)+"?field=answer", headers=self.header, json={}).json()
+               ans_resp = requests.get(self.upload_faq_json_answer_url + "/" + str(question_id), headers=self.header, json={}).json()
                code = int(ans_resp["code"])
                msg = str(ans_resp["message"])
                if code != 0:
                  raise BfEngineException(code=code, msg=msg)
-               for ans in ans_resp['data']['answers']:
-                   self.delete_answer(ans['id'])
+               answer_id_list= []
+               for ans in ans_resp['data']:
+                   answer_id_list.append(ans['id'])
+               self.delete_answer_list(answer_id_list)
                for insert_answer in answer_request_list:
                    insert_data = {
                        "answer":insert_answer,
@@ -605,6 +607,21 @@ class QACaller(CallerBase):
             raise BfEngineException(code=code, msg=msg)
         return
 
+    def delete_answer_list(self, answer_id_list):
+        """
+        删除答案
+        :return:
+        """
+        params = {
+            'records': answer_id_list
+        }
+        resp = requests.delete(self.upload_faq_json_answer_url, headers=self.header, json=params).json()
+        code = int(resp["code"])
+        msg = str(resp["message"])
+        if code != 0:
+            raise BfEngineException(code=code, msg=msg)
+        return
+
     def query_category_list(self):
         resp = requests.get(self.operate_faq_category_url, headers=self.header,
                             json={}).json()
@@ -676,15 +693,16 @@ class QACaller(CallerBase):
         similar_sq_result = []
         sq_list = [];
         sq_map = {};
+        answer_map = {};
         log.info(self.module + "开始")
         category_ids_list = self.get_all_sub_list(category_ids)
         log.info(self.module + "子目录查询完毕")
-        self.get_all_sq_under_input_folders(category_ids_list, sq_list, sq_map)
+        self.get_all_sq_under_input_folders(category_ids_list, sq_list, sq_map, answer_map)
         log.info(self.module + "sq获取完毕")
         converter = Converter('zh-hans')
         params = {"Text":converter.convert(user_inputs).lower(),'UniqueId':str(random.randint(100,10000)),"IsRelease": online,'Robot':self.app_id}
-        print("params: "+str(params))
-        print("predict request url: "+self.get_predict_qa_list_url)
+        log.info("params: "+str(params))
+        log.info("predict request url: "+self.get_predict_qa_list_url)
         resp = requests.request("POST", self.get_predict_qa_list_url, headers=self.header, json=params).json()
         code = int(resp["code"])
         msg = str(resp["message"])
@@ -694,26 +712,27 @@ class QACaller(CallerBase):
         log.info(self.module + "预测结果获取完毕")
         for match_sq in resp['data']:
             if 'sqId' in match_sq and match_sq['sqId'] in sq_list:
-               ans_list = [];
                match_sq['category_id'] = str(sq_map.get(match_sq['sqId']))
-               ans_resp = requests.get(self.upload_faq_json_sq_url + "/" + str(match_sq['sqId'])+"?field=answer", headers=self.header, json={}).json()
-               code = int(ans_resp["code"])
-               msg = str(ans_resp["message"])
-               if code != 0:
-                  raise BfEngineException(code=code, msg=msg)
-               for ans in ans_resp['data']['answers']:
-                   ans_list.append(ans['answer'])
-               match_sq['answer'] = ans_list
-               similar_sq_result.append(match_sq)
+               if(len(category_ids_list)>0) and match_sq['category_id'] in category_ids_list:
+                      similar_sq_result.append(match_sq)
+               else:
+                      similar_sq_result.append(match_sq)
         log.info(self.module + "结果处理完毕")
         topn = int(max_topn)
         similar_sq_result = sorted(similar_sq_result, key=lambda x: x["score"], reverse=True)[:topn]
+        for result_sq in similar_sq_result:
+            ans_list = [];
+            ans_resp_list = [];
+            ans_resp_list = answer_map.get(result_sq['sqId'])
+            for ans in ans_resp_list:
+                ans_list.append(ans['answer'])
+            result_sq['answer'] = ans_list
         log.info(self.module + "返回结果")
         return similar_sq_result
 
-    def get_all_sq_under_input_folders(self, category_ids_list, sq_list, sq_map):
+    def get_all_sq_under_input_folders(self, category_ids_list, sq_list, sq_map,answer_map):
         data = {"search": [{"keyword": "", "field": "sq"}],
-                "conditions": {"category": {"id_list": category_ids_list, "logical_op": "and"}}}
+                "conditions": {"category": {"id_list": [], "logical_op": "and"}}}
         sq_resp = requests.post(self.search_faq_json_question_list_url, headers=self.header, json=data).json()
         code = int(sq_resp["code"])
         msg = str(sq_resp["message"])
@@ -723,6 +742,8 @@ class QACaller(CallerBase):
             sq_list.append(sq['id'])
             kv = {sq['id']: sq['category_id']}
             sq_map.update(kv)
+            kvanswer = {sq['id']: sq['answers']}
+            answer_map.update(kvanswer)
 
     def get_all_sub_list(self, category_ids):
         category_ids_list = []
